src.simple_sign.types API documentation
Description: Simple-sign data types

# Module `src.simple_sign.types`

Simple-sign data types

## Classes

`class Alias (alias: str, address: str, staking: str, tx: str)`

  Alias(alias: str, address: str, staking: str, tx: str)

  Expand source code

      @dataclass
      class Alias:
          alias: str
          address: str
          staking: str
          tx: str

  ### Class variables

  `var address : str`
  `var alias : str`
  `var staking : str`
  `var tx : str`